@@ -16,11 +16,19 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
+// $URL$
+// $Id$
+// SPDX-License-Identifier: GPL-3.0+
+//
 // Author(s)     : Waqar Khan <wkhan@mpi-inf.mpg.de>
 
 #ifndef CGAL_ARR_POLYLINE_TRAITS_2_H
 #define CGAL_ARR_POLYLINE_TRAITS_2_H
 
+#include <CGAL/license/Arrangement_on_surface_2.h>
+
+#include <CGAL/disable_warnings.h>
+
 /*! \file
  * The traits-class for the linear piece-wiese(polyline) type of curves of the
  * arrangement package.
@@ -47,6 +55,10 @@ class Arr_polyline_traits_2 : public Arr_polycurve_traits_2<SegmentTraits_2> {
 public:
   typedef SegmentTraits_2                             Segment_traits_2;
 
+  // For completeness
+  typedef typename Segment_traits_2::Curve_2            Segment_2;
+  typedef typename Segment_traits_2::X_monotone_curve_2 X_monotone_segment_2;
+
 private:
   typedef Arr_polyline_traits_2<Segment_traits_2>     Self;
   typedef Arr_polycurve_traits_2<Segment_traits_2>    Base;
@@ -69,7 +81,7 @@ public:
   typedef typename Base::Are_all_sides_oblivious_tag
     Are_all_sides_oblivious_tag;
 
-  typedef typename Base::X_monotone_subcurve_2         X_monotone_subcurve_2;
+  typedef typename Base::X_monotone_subcurve_2        X_monotone_subcurve_2;
   typedef typename Base::Subcurve_2                   Subcurve_2;
 
   typedef typename Base::Point_2                      Point_2;
@@ -130,7 +142,7 @@ public:
    */
   class Push_back_2 : public Base::Push_back_2 {
   protected:
-    typedef Arr_polyline_traits_2<SegmentTraits_2>     Polyline_traits_2;
+    typedef Arr_polyline_traits_2<Segment_traits_2>     Polyline_traits_2;
 
   public:
     /*! Constructor. */
@@ -243,7 +255,7 @@ public:
    */
   class Push_front_2 : public Base::Push_front_2 {
   protected:
-    typedef Arr_polyline_traits_2<SegmentTraits_2>     Polyline_traits_2;
+    typedef Arr_polyline_traits_2<Segment_traits_2>     Polyline_traits_2;
 
   public:
     /*! Constructor. */
@@ -297,7 +309,7 @@ public:
     /*! Append a point `p` to an existing polyline `xcv` at the front. */
     void operator()(const X_monotone_curve_2& xcv, Point_2& p) const
     {
-      const SegmentTraits_2* geom_traits =
+      const Segment_traits_2* geom_traits =
         this->m_poly_traits.subcurve_traits_2();
       CGAL_precondition_code
         (
@@ -597,4 +609,6 @@ public:
 
 } // namespace CGAL
 
+#include <CGAL/enable_warnings.h>
+
 #endif
